%check: 3.1.2022

%Important note: The figure plots the time-Ta response of the price level
%(in deviations) from steady state. However, since P(Ta-1)=0 by
%assumption, we have pi(Ta)=P(Ta)-P(Ta-1)=P(Ta). Therefore, the time Ta
%change in prices is identical to the time Ta change in inflation.

clear;
clc;
addpath('Functions')
 
n=2;
Tstar=1250;           %T*
tstar=Tstar-1;    %1-period shock
ibar=-1/400;          %T*-1 shock size
 
 
Y_0{1}=zeros(n,1,Tstar); %endo vars for param. 1
Y_0{2}=zeros(n,1,Tstar); %endo vars for param. 2
lam_max=zeros(4);        %record max eig--which is simply spectral radius of F in this class of models
 
 
 
 
%% Simple NK, p=1
Omeg=zeros(n,n,Tstar+1); %b matrices
Ct=zeros(n,1,Tstar+1);   %a matrices 
 
%----Post-shock REE
%----STRUCTURAL PARAMETERS
        beta=.99;
        phi=1.5; 
        sigma=.2;
        kappa=.11;
 
  
 %----RE solution for t>T*: x=(y pi)'
        Ap=[1 sigma*(1+phi);...
            -kappa/(1+beta) 1];
        Bp=[1 sigma;...
            0 beta/(1+beta)];
        Cp=[0 0;...
            0 1/(1+beta)];
        Dp=zeros(2);
 
        A=Ap\Bp;
        B=Ap\Cp;
        C=Ap\Dp;
 
        [DET,FCC,OmegaK,GammaK,FK,IRs]=fmlre(A,B,C,zeros(2));
         
         
Omeg(:,:,Tstar+1)=OmegaK;   %collects b matrices
OmegaKpost=OmegaK;
Ct(:,:,Tstar+1)=zeros(2,1); %collects a matrices
 
 
%----FG shock-horizon
        Ap=[1 sigma;...
            -kappa/(1+beta) 1];
        Bp=[1 sigma;...
            0 beta/(1+beta)];
        Cp=[0 0;...
            0 1/(1+beta)];
         
        A=Ap\Bp;
        B=Ap\Cp;
        gam1=Ap\[-sigma*ibar;0];  %one-unit shock introduced as intercept.       
 
  
for t=1:Tstar-tstar
Omeg(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\B;
Ct(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\(gam1+A*Ct(:,:,Tstar+2-t));
end
        
%----pre-FG shock
 
        Ap=[1 sigma;...
            -kappa/(1+beta) 1];
        Bp=[1 sigma;...
            0 beta/(1+beta)];
        Cp=[0 0;...
            0 1/(1+beta)];
         
        A=Ap\Bp;
        B=Ap\Cp;
        gam2=Ap\[0;0];        
 
  
for t=Tstar-tstar+1:Tstar
Omeg(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\B;
Ct(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\(gam2+A*Ct(:,:,Tstar+2-t));
end
   
 
for h=1:Tstar
Y_0{1}(:,:,h+1)=Ct(:,:,Tstar-h+2);
end
 
   
 
   
%% Simple NK, p<1
Omeg=zeros(n,n,Tstar+1);
Ct=zeros(n,1,Tstar+1);
 
%----Post-shock REE
%----STRUCTURAL PARAMETERS
p=.999;         
         
Omeg(:,:,Tstar+1)=OmegaKpost;   %collects b matrices
Ct(:,:,Tstar+1)=zeros(2,1); %collects a matrices
 
 
%----FG shock-horizon
        Ap=[1 sigma;...
            -kappa/(1+beta) 1];
        Bp=[1 sigma;...
            0 beta/(1+beta)];
        Cp=[0 0;...
            0 1/(1+beta)];
         
        A=Ap\Bp;
        B=Ap\Cp;
        gam1=Ap\[-sigma*ibar;0];  %one-unit shock introduced as intercept.       
        
for t=1:Tstar-tstar
Omeg(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\B;
Ct(:,:,Tstar+1-t)=(eye(n)-A*Omeg(:,:,Tstar+2-t))\(gam1+A*Ct(:,:,Tstar+2-t));
end
        
%----pre-FG shock
 
        Ap=[1 sigma;...
            -kappa/(1+beta) 1];
        Bp=[1 sigma;...
            0 beta/(1+beta)];
        Cp=[0 0;...
            0 1/(1+beta)];
         
        A=Ap\Bp;
        B=Ap\Cp;
        gam2=Ap\[0;0];        
 
  
for t=Tstar-tstar+1:Tstar
Omeg(:,:,Tstar+1-t)=(eye(n)-A*(p*Omeg(:,:,Tstar+2-t)+(1-p)*OmegaKpost))\B;
Ct(:,:,Tstar+1-t)=(eye(n)-A*(p*Omeg(:,:,Tstar+2-t)+(1-p)*OmegaKpost))\(gam2+p*A*Ct(:,:,Tstar+2-t));
end
   
   
   
for h=1:Tstar
Y_0{2}(:,:,h+1)=Ct(:,:,Tstar-h+2);
end

   
   
%% Figures
phor=1000;
   
   
figure(4)
ylim([0 .061])
xlim([0 1000])
% subplot(2,2,4)
%line([0 phor-2],[0 0],'Color','blue','LineStyle','--')
set(gca,'FontName', 'Times','FontSize',12);
plot(0:phor-2,squeeze(Y_0{1}(2,:,2:phor))*400,'-.k',"Linewidth",3)
ylabel('Inflation')
xlabel('\Delta_p')
hold on
plot(0:phor-2,squeeze(Y_0{2}(2,:,2:phor))*400,'r',"Linewidth",3)
hold on
 set(gcf,'position',[10,10,450,325])
  title('Price Level Targeting','FontSize',14,'FontName', 'Times','FontWeight','Normal')
xlabel('\Delta_p','FontSize',14,'FontName', 'Times')
ylabel('Inflation','FontSize',14,'FontName', 'Times')
legend("\eta=1", "\eta=0.999",'Location','southeast')
 
