(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    107164,       2474]
NotebookOptionsPosition[    105064,       2435]
NotebookOutlinePosition[    105435,       2451]
CellTagsIndexPosition[    105392,       2448]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "file", " ", "recreates", " ", "Figure", " ", "1", " ", "in", 
    " ", "Gibbs", " ", "and", " ", "McClung", " ", 
    RowBox[{"(", "2023", ")"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Defining", " ", "the", " ", "model"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"A0", " ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "0", ",", 
         RowBox[{"\[Sigma]", " ", "\[Chi]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "\[Kappa]"}], ",", " ", "1", ",", " ", "0"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"B0", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"M", ",", 
         RowBox[{"\[Sigma]", " ", "\[Chi]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", " ", 
         RowBox[{"Mf", " ", "\[Beta]"}], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[CapitalGamma]0", " ", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\[Sigma]", " ", "\[Chi]", " ", "r"}], "}"}], ",", 
       RowBox[{"{", "0", "}"}], ",", 
       RowBox[{"{", "r", "}"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"B", "=", 
    RowBox[{
     RowBox[{"Inverse", "[", "A0", "]"}], ".", "B0"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"G", " ", "=", " ", 
    RowBox[{
     RowBox[{"Inverse", "[", "A0", "]"}], ".", 
     "\[CapitalGamma]0"}]}]}]}]], "Input",
 CellChangeTimes->{{3.845056567022184*^9, 3.8450567500097666`*^9}, {
  3.8804969830697403`*^9, 3.8804970252846513`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"91f35138-8d69-4d58-b225-39ad68149a62"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"M", ",", 
     RowBox[{"\[Sigma]", " ", "\[Chi]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"M", " ", "\[Kappa]"}], ",", 
     RowBox[{
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8450567669039593`*^9, 3.845078279258746*^9, 
  3.8475001811126237`*^9, 3.8490421075641155`*^9, 3.8852542786203337`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"68f9af6a-fac1-4bed-9b8f-38b699d42eee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "0", "}"}], ",", 
   RowBox[{"{", "r", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8450567669039593`*^9, 3.845078279258746*^9, 
  3.8475001811126237`*^9, 3.8490421075641155`*^9, 3.885254278624163*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"022247b5-654f-48c5-b8c4-ed9d0a42d29b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"IE", "-", 
    RowBox[{"stability", " ", "analysis"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"B", "//", "MatrixForm"}], "\n", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {"M", 
        RowBox[{"\[Sigma]", " ", "\[Chi]"}], "0"},
       {
        RowBox[{"M", " ", "\[Kappa]"}], 
        RowBox[{
         RowBox[{"Mf", " ", "\[Beta]"}], "+", 
         RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], "0"},
       {"0", "0", "0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"Eigenvalues", "[", "B", "]"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"M", "\[Rule]", "1"}], ",", 
       RowBox[{"Mf", "\[Rule]", "1"}], ",", 
       RowBox[{"\[Chi]", "\[Rule]", "0.1"}], ",", 
       RowBox[{"\[Beta]", "\[Rule]", ".99"}], ",", 
       RowBox[{"\[Kappa]", "\[Rule]", "0.02"}], ",", 
       RowBox[{"\[Sigma]", "\[Rule]", "0.5"}]}], "}"}]}], "//", "Simplify"}], 
   "\n", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.963558647492632`", ",", "1.027441352507368`"}], 
    "}"}], "\n", 
   RowBox[{"IEstab", " ", "=", 
    RowBox[{
     RowBox[{"Eigenvalues", "[", "B", "]"}], "//", "Simplify"}]}], "\n", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"M", "+", 
        RowBox[{"Mf", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "-", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
           "2"]}]]}], ")"}]}], ",", 
     RowBox[{
      FractionBox["1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"M", "+", 
        RowBox[{"Mf", " ", "\[Beta]"}], "+", 
        RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
        SqrtBox[
         RowBox[{
          RowBox[{
           RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
           "2"]}]]}], ")"}]}]}], "}"}], "\n", 
   RowBox[{"Reduce", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{"M", "+", 
          RowBox[{"Mf", " ", "\[Beta]"}], "+", 
          RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
          SqrtBox[
           RowBox[{
            RowBox[{
             RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"M", "+", 
               RowBox[{"Mf", " ", "\[Beta]"}], "+", 
               RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
             "2"]}]]}], ")"}]}], "<", "1"}], "&&", 
      RowBox[{"0", "<", "M", "\[LessEqual]", "1"}], "&&", 
      RowBox[{"0", "<", "Mf", "\[LessEqual]", "1"}], "&&", " ", 
      RowBox[{"0", "<", "\[Beta]", "<", "1"}], "&&", 
      RowBox[{"\[Kappa]", ">", "0"}], "&&", 
      RowBox[{"\[Sigma]", ">", "0"}], "&&", " ", 
      RowBox[{"\[Chi]", ">", "0"}]}], ",", "Mf"}], "]"}], "\n"}]}]], "Input",
 CellChangeTimes->{{3.845056778039879*^9, 3.845056785901249*^9}, {
  3.8804970546456165`*^9, 3.8804970947724185`*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"65099b3b-d3ca-469e-b624-ab2104b13853"],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"M", 
      RowBox[{"\[Sigma]", " ", "\[Chi]"}], "0"},
     {
      RowBox[{"M", " ", "\[Kappa]"}], 
      RowBox[{
       RowBox[{"Mf", " ", "\[Beta]"}], "+", 
       RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], "0"},
     {"0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.885254278740311*^9},
 CellLabel->
  "Out[6]//MatrixForm=",ExpressionUUID->"2cbdc684-9ec1-4d4d-ab1f-\
73ca6f4c16d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"M", ",", 
     RowBox[{"\[Sigma]", " ", "\[Chi]"}], ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"M", " ", "\[Kappa]"}], ",", 
     RowBox[{
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ",", "0"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8852542787472754`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"ff8d8d3e-7300-42f6-8796-67f83e082e36"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0.963558647492632`", ",", "1.027441352507368`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8852542787845497`*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"4d53ed8c-2a68-40f4-a8f2-49d5589a8a3b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0.963558647492632`", ",", "1.027441352507368`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8852542787895107`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"c1263589-744c-44f4-b3ac-ee756e56565a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"M", "+", 
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"M", "+", 
           RowBox[{"Mf", " ", "\[Beta]"}], "+", 
           RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
         "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"M", "+", 
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"M", "+", 
           RowBox[{"Mf", " ", "\[Beta]"}], "+", 
           RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
         "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8852542788383794`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"1ea8241f-ee53-45e8-8a12-3a2e2a30330e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"M", "+", 
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "-", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"M", "+", 
           RowBox[{"Mf", " ", "\[Beta]"}], "+", 
           RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
         "2"]}]]}], ")"}]}], ",", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"M", "+", 
      RowBox[{"Mf", " ", "\[Beta]"}], "+", 
      RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], "+", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"M", "+", 
           RowBox[{"Mf", " ", "\[Beta]"}], "+", 
           RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], ")"}], 
         "2"]}]]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.8852542788568835`*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"e3b4e413-94f5-40b6-b3c3-e1444ec7aa5a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Chi]", ">", "0"}], "&&", 
  RowBox[{"\[Sigma]", ">", "0"}], "&&", 
  RowBox[{"0", "<", "M", "<", "1"}], "&&", 
  RowBox[{"0", "<", "\[Kappa]", "<", 
   FractionBox[
    RowBox[{"1", "-", "M"}], 
    RowBox[{"\[Sigma]", " ", "\[Chi]"}]]}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"0", "<", "\[Beta]", "<", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", "M", "+", 
         RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "M"}]]}], "&&", 
      RowBox[{"0", "<", "Mf", "\[LessEqual]", "1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Beta]", "\[Equal]", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", "M", "+", 
         RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "M"}]]}], "&&", 
      RowBox[{"0", "<", "Mf", "<", "1"}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", "M", "+", 
         RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", "M"}]], "<", "\[Beta]", "<", "1"}], "&&", 
      RowBox[{"0", "<", "Mf", "<", 
       FractionBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", "M", "+", 
         RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
        RowBox[{
         RowBox[{"-", "\[Beta]"}], "+", 
         RowBox[{"M", " ", "\[Beta]"}]}]]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.8852542789239407`*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"f0db2aed-e089-4c2a-a64b-dfe4d3ec094f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Functions", " ", "for", " ", "THANK", " ", "model", " ", "parameters"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"CalcM", " ", "[", "\[Chi]_", "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"\[Lambda]", "-", "1"}], ")"}], "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "0.96"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{"\[Lambda]", "*", "0.21"}]}], ")"}]}]}]}], ")"}], " ", "/.", 
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"0.79", "/", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           RowBox[{"\[Lambda]", "*", "0.21"}]}], ")"}]}], "\[Equal]", 
        "\[Chi]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Calc\[Chi]", "[", "M_", "]"}], ":=", 
     RowBox[{
      RowBox[{"0.79", "/", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"\[Lambda]", "*", "0.21"}]}], ")"}]}], "/.", 
      RowBox[{"NSolve", "[", 
       RowBox[{
        RowBox[{"1", "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"\[Lambda]", "-", "1"}], ")"}], "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "0.96"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"\[Lambda]", "*", "0.21"}]}], ")"}]}]}]}], "\[Equal]", 
        "M"}], "]"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.847748936139678*^9, 3.8477489712698107`*^9}, {
  3.8477490772569575`*^9, 3.8477490950596385`*^9}, {3.8477491823935957`*^9, 
  3.8477492254133854`*^9}, {3.84774962254881*^9, 3.847749712385007*^9}, {
  3.880497113348078*^9, 3.880497127891799*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"29d8c1d7-d48d-4ade-80fe-ed20a4c2f1f3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Figures", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"g1", " ", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"M", "\[Rule]", "1"}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Chi]", ",", 
           RowBox[{"-", "0.5"}], ",", "2"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times New Roman\>\""}], 
           "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\[Chi]\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Largest Eigenvalue\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}]}], "}"}]}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Directive", "[", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed", ",", 
               RowBox[{"Thickness", "[", "0.0015", "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "0.5"}], ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"2", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
        "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"M", "\[Rule]", "0.85"}], ",", 
            RowBox[{"Mf", "\[Rule]", "0.8"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Chi]", ",", 
           RowBox[{"-", "0.5"}], ",", "2"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dotted"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"M", "\[Rule]", 
             RowBox[{
              RowBox[{"CalcM", "[", "\[Chi]", "]"}], "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Chi]", ",", 
           RowBox[{"-", "0.5"}], ",", "2"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Dashed"}], "}"}]}]}], "]"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g2", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"M", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times New Roman\>\""}], 
           "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<M\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Largest Eigenvalue\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}]}], "}"}]}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Directive", "[", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed", ",", 
               RowBox[{"Thickness", "[", "0.0015", "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
        "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"Mf", "\[Rule]", "0.8"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"M", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dotted"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", 
             RowBox[{"Calc\[Chi]", "[", "M", "]"}]}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"M", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Dashed"}], "}"}]}]}], "]"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g3", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"M", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"Mf", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6", ",", "1.3"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times New Roman\>\""}], 
           "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\!\(\*SuperscriptBox[\(M\), \(f\)]\)\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Largest Eigenvalue\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}]}], "}"}]}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Directive", "[", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed", ",", 
               RowBox[{"Thickness", "[", "0.0015", "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
        "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"M", "\[Rule]", "0.85"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"Mf", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dotted"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "0.84311"}], ",", 
            RowBox[{"M", "\[Rule]", "0.97011"}], ",", 
            RowBox[{"\[Kappa]", "\[Rule]", "0.11"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"Mf", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Dashed"}], "}"}]}]}], "]"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g4", "=", 
     RowBox[{"Show", "[", 
      RowBox[{
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"M", "\[Rule]", "1"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Kappa]", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", "Black"}], ",", 
         RowBox[{"PlotRange", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"0", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.6", ",", "2"}], "}"}]}], "}"}]}], ",", 
         RowBox[{"LabelStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Times New Roman\>\""}], 
           "}"}]}], ",", 
         RowBox[{"Frame", "\[Rule]", "True"}], ",", 
         RowBox[{"FrameLabel", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<\[Kappa]\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Largest Eigenvalue\>\"", ",", 
              RowBox[{"FontSize", "\[Rule]", "24"}]}], "]"}]}], "}"}]}], ",", 
         RowBox[{"Epilog", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Directive", "[", 
             RowBox[{"{", 
              RowBox[{"Black", ",", "Dashed", ",", 
               RowBox[{"Thickness", "[", "0.0015", "]"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1"}], "}"}]}], "}"}], "]"}]}], "}"}]}]}], 
        "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "1"}], ",", 
            RowBox[{"Mf", "\[Rule]", "0.8"}], ",", 
            RowBox[{"M", "\[Rule]", "0.85"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Kappa]", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Red", ",", "Dotted"}], "}"}]}]}], "]"}], ",", 
       RowBox[{"Plot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"M", "+", 
             RowBox[{"Mf", " ", "\[Beta]"}], "+", 
             RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}], "+", 
             SqrtBox[
              RowBox[{
               RowBox[{
                RowBox[{"-", "4"}], " ", "M", " ", "Mf", " ", "\[Beta]"}], 
               "+", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{"M", "+", 
                  RowBox[{"Mf", " ", "\[Beta]"}], "+", 
                  RowBox[{"\[Kappa]", " ", "\[Sigma]", " ", "\[Chi]"}]}], 
                 ")"}], "2"]}]]}], ")"}]}], "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"\[Chi]", "\[Rule]", "0.84311"}], ",", 
            RowBox[{"Mf", "\[Rule]", "1"}], ",", 
            RowBox[{"M", "\[Rule]", "0.97011"}], ",", 
            RowBox[{"\[Sigma]", "\[Rule]", "0.2"}], ",", 
            RowBox[{"\[Beta]", "\[Rule]", "0.99"}]}], "}"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Kappa]", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
           RowBox[{"Blue", ",", "Dashed"}], "}"}]}]}], "]"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Figure1", " ", "=", 
    RowBox[{"GraphicsGrid", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"g1", ",", "g2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"g3", ",", "g4"}], "}"}]}], "}"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "900"}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.8450573831591268`*^9, 3.845057456881915*^9}, {
   3.845058779443221*^9, 3.845059237890088*^9}, {3.845059326187208*^9, 
   3.8450594036126137`*^9}, {3.8450594725991*^9, 3.845059527471517*^9}, {
   3.8450596166976347`*^9, 3.8450597131650743`*^9}, {3.8450597544340754`*^9, 
   3.84505983068161*^9}, {3.8450598660065384`*^9, 3.845059901994341*^9}, {
   3.845059942225387*^9, 3.845060025605836*^9}, 3.8450601298500323`*^9, {
   3.8450601980741787`*^9, 3.845060211325405*^9}, {3.845060247029396*^9, 
   3.8450602752174916`*^9}, {3.8450603367132516`*^9, 3.845060356738782*^9}, {
   3.8450604667519684`*^9, 3.845060563747961*^9}, {3.845060607695648*^9, 
   3.845060694286113*^9}, {3.845078125335245*^9, 3.8450781278256884`*^9}, {
   3.8475001136417274`*^9, 3.8475001556658792`*^9}, {3.8475001944460316`*^9, 
   3.8475001967281027`*^9}, 3.8477469955516872`*^9, {3.8477470319354153`*^9, 
   3.8477472081618147`*^9}, {3.84774723837266*^9, 3.8477472794666176`*^9}, {
   3.8477473839484243`*^9, 3.8477473845310564`*^9}, {3.8477474477168827`*^9, 
   3.8477474540753927`*^9}, {3.8477475580632296`*^9, 3.847747571386712*^9}, {
   3.8477476064897523`*^9, 3.847747707966254*^9}, {3.847747742942904*^9, 
   3.847747756943776*^9}, {3.847748177801552*^9, 3.847748183023919*^9}, {
   3.847748387389717*^9, 3.8477484419915824`*^9}, {3.8477486212860856`*^9, 
   3.8477486242498703`*^9}, {3.847748658887766*^9, 3.847748670211193*^9}, {
   3.8477487182675276`*^9, 3.8477488688970127`*^9}, 3.847748927458866*^9, {
   3.847749009235823*^9, 3.8477490168954144`*^9}, 3.8477491375583053`*^9, 
   3.847749169507064*^9, {3.8477492725105095`*^9, 3.84774928531728*^9}, {
   3.8477499506864166`*^9, 3.847749956052965*^9}, {3.847749986790863*^9, 
   3.847749991003766*^9}, {3.8477500339066787`*^9, 3.847750039425664*^9}, {
   3.8477500930874577`*^9, 3.847750102608484*^9}, {3.8477504188716803`*^9, 
   3.847750436933323*^9}, 3.8490420654343452`*^9, {3.880497140559094*^9, 
   3.880497144536318*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"b55b0b1f-5c59-4c11-ae68-af744d117ace"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJwV0n881HkeB3BGbEndTiWHiqEcLs2RTUQv7R2KsOWItJlpcLJE2pZatJ0Y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             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$2338#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJwV0H00lIkeB3BNytKrNnmZdjPGtc22qLZtEnO/1Rpcnd6jN7uE1HW2a0PI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             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$2445#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVzXk01WkAxnFJGo7RqFGWjOWEtttqYrh6ULeiSIksNZZ2LeYU1WQpZe2U
NLaUpWSPdKQhRr8OqnEtSS6jwY1CXbn7y5V4x/zxnO/5/PUYBwTtPqSspKTk
PLP/K8u0bKSUz+y6x4kbZguRKvLqCJLxmTW/FhzfbiuElX0Ynz/EZ177a5ws
m3HEx+eEaeEzKVLaeG6jEOornEwu3eEzJzWPj6rZCWFStS9UyZLPTDC2/es3
CeHaHsmadaqPSXb5sSLLUYgS1eabyj09zNVV92vfeAihnWzQeDC4m9HR2rx4
ZYgQzn6LHsdv6WReTS7Rrk8Swun74wl5S98yvQNR78cfCzFaO/7IPuE1Y5mj
VR3eLcRg37Hi2o2NjF/vcJYKFYLt6BGpOFLHaGuXKUKXi2At+BLiEFDJtLiO
5s3xFOHMhYwjtpV5jE2gw7p50SKwP/Xdtm6OhlPiYG1hlQiLFI2GnNcPsSp5
h5bviAhTaapzB3g18FjWnF4+T4y0tvT+XUUN2FoaV76MJcbNLl9vlpyLzuBT
OxscxUjl8r4u+dCG8sIrpoJjYmT9bbyXze5An3FNdsJVMbpiXyjd9OnC7C7P
3UNFYviZlNjEPHuHsVBORUuzGHoRgvqq4V4YpSytXSEU4493T4Sc4veQ3V74
1mCBBBXRjcoVngPQDD+rb2glwSmt+Fo7wQcUFtp12/pI0KYueJ6ZOYhNF1RY
gkgJmj6OBepaDCN4eWlZXL4EB1s9MtLrPkGb2+rI50qQa+q5UHBagEie+YJn
UgnC98+x9FL9gn0fqzLddaSgynvu3qoZxdxkvZ4Qeyl+qiKJPUdFkB0ITV8T
KIUg3zg5O0wMkwitkXOJUqQv1VV56i6Bq1p82+ZqKVJuH37lbySFuqlpfXy/
FL7J+1s1hqXoGHV7iu9kmNqcN5H9TIZ+Xkfd7+tk+DTocL4uVo4TT8xbf/CW
ocB2rX6LP0GzZqo+K1qG8ugQrSOsMfxWxt6TXirDNfcD22eTMThFvej05clg
3XOvKLZlHNzMG+4PlOSwcNvgcydNgYyRR1Y/L5NDOVJ/bdrpCXRf2bib4y5H
9oZipxTHr7gULq4puCRHXE9Cpcn8SfQcdnhoXSQH55eGbbdGJmGOc2v28ORw
idnJyvzzGx5Xv8lPm5bDzCfKPTd8CtwMb3Mjc4L2IbWcJPdpGNjx2le7EXAD
Bu3nG1KY5eS6+IUR9KoUKFJMKIiTcoBOOIE4/2iZrhnFQH3V2bYZa4+MLDZm
URwrWZVrd5HA74x0fLUNhULDYp7xZYLxK7TUeS/FtJ6b6UAswZI8Xb34GxQu
1712HkoisNz6b5tGEsX7usXXDZIJnD5nxCamUphYs5p5Mw5iGZG0TIrAKAuX
LakE1U/M2vIfUBSWtPubpxO4vlwf0/CKQvWf6ZefswgOHCXsbU0UFzRP6OZk
E5xVr5Q1tVIoiYxOet8luONi7f+WRxGyw0+n6R7BUKcde+ADhWHHioiSXIKJ
88qyQ8MUkxXN7w7mEWjoNxR9FlCkXCy3MsgnWOe7dZFEQrEyeLviegEBZ5Za
azCZ+RNNeW0pJPC8z41SKCg2jMv+mp5xIOeaTdg3igALlnFlEUH4sLOUUgp1
16KYoGKC/wDy+pBi
             "]]},
           Annotation[#, "Charting`Private`Tag$2513#1"]& ]}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0.6},
       DisplayFunction->Identity,
       Epilog->{
         Directive[{
           GrayLevel[0], 
           Dashing[{Small, Small}], 
           Thickness[0.0015]}], 
         LineBox[{{-0.5, 1}, {2, 1}}]},
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Largest Eigenvalue\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox["\"\[Chi]\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->{FontFamily -> "Times New Roman"},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0, 2}, {0.6, 1.3}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {192., -118.66252583997979}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJwV0Xs0lHkYB/BRWsqhdD3D0lJaXURWtlK+yZ3Y3I5sQrmVEJNIaUXEduNE
USgxtbWzmcqoZCq3ZTlUbtGaZqRJZHh/71sIp2bf/eM5z/n88z3n+T4Gew96
hs7gcDhu7Py/XUIH26qHfKylHnlDK9YRqNrqxMi4FuAvk30wYf3TtfzCcq4d
7KSWHyxYu7Z23y/ieiOBs2RoG2vfkIknF7ghOFBUPBnA+o1phu05bhziL2u5
57EuXvTLqdPcNIzbqDaomxOkqJf/+Ds3F06GahyK9U6/60JC85H1oK+RtiDQ
UKb4O+oL0RpaWT5gSWDkMTpYd0aEZZyZY+83ECQ834j8z5UI9O7KMLYiWCLS
lqqoPION0pXnv4XgQb9ty4vNteip8YvpBUFtRJGun6IeldutByK3EYyt2DL3
TlQj0k6V0KN2BDMmBfN0jZoR7fa5+h9HAktl0AOvshbkmZHeHBeCljSL5w2r
XqDOvrGH50awNHt48vboS9QYay+t3EEwPCGTdpm141E6L4F4EfA/VjVrne+A
13dH/Yt8CbT0/qDk8k7sEz6citpFcHZ/RVjx8lfIMaIHTAMJxrcK5PuSu/Ho
tVNJcjBBnHm9aHFdD3uXtVtdOIGsrP5Mm8G/CF7TpyuIJJiO6CxYebQXx6fW
xrXEEqy2UfsWViWBtXndAnk8gWOJQfi9JVK8+uvZeEMS25deoOFbfxk66q+8
v5FKsEbho9Ht1odoZ46sKZNgwVyiXj/Vh+qGFltFFvv/ZwXCZYVvMXrJjqed
R3DAour1bNd+XCxXXRh2jUDgvLf46Xg/ok/8JrC6xfY5rDNv4NI7aO5YN61/
j6DCy3Fmrp0ccVuLZaerCJKd0q+JBuQI8fias6iBwOCNS09p+nvo8rOtbNsI
Nv2clss1H0B83J7YGCmBv/6LSZWOAZgMiU3bh9n85nP9MSkf8CVz/Sf+NEG+
akCc5/JB2D9OqmjSoLFAWlEyo34QPJsahZoejVnHU7w3xg5BnN+YcXQdDc7t
AGH//I/IKckP3uVAg3dFeG5+7Uc8rJn4Wz+QxpPVmera0cOw38lra0ykoe3C
W5OqpUDNRZ+Tg7k0JCYvOxLFCqQaXxUzIhp3r2K5PGAE++WZOoe7aOwWWmrr
fRtB6OzATMkEjRPp11Mkf47i1YVNJ3R+YHBnUK9AazsF/7tiSZQTg8yi9CCp
OwWzvLFZxs4MQjxHjMo8KPiJboT0s/5eLL7r5ksh7H5Ira8rg9NZuxrO7qWg
f36V0s6dwT7Ly/ScRArhxlpJK70ZGKYtdFK7SeGhgMvTCWLwbUOSZvctCsL9
Evte1q9H3rXfFFBwrqp3L9zDINu3fLfDPQqJ9l+U+sEMlKs8D6WLKSxemyFb
EcZA0pZ1dWYHhTlHJrO2RjJ4dGoiuKOLAv/gryLVKAa5VoErS3soTJ8s1Wxi
7XpjrWiblEJqqyTA8yCDx0dam1KGKLSfjDkWzmNwyWR9loeCAhOQ52ByiEFs
f6G3AUVB70KqwyfWxtsjZdWfKSQY5siTDzNQVenkZ09QeEqVpTrEM+irsIoI
mqKweeyYj2YCA3FEqanZVwoWLmP+nazzlmqMKZUUmr8sulxwhMF/E6yBFw==

             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$4351#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJwV0Hk41HkABvAxtNhBJMcIPYoOxyrpUnptypGjcqzKkaRYWy2lp+OpR9Mi
HYysRzJUylZYTUIrR6cuERo1RCNjsnxnxnd+ntDJ2j/e530+/73PaxX1e8AO
NovF8pvM/71ux0Db/cHgVWPqJTXeOgQa7mbxPVxnGJsfsQyd9KKLufkV3DWw
jcpK2TVpn2bxrQJuEIZ0+OH8SYdEj9VncaNhxZI6v570O8cT7uncRGz5o5q3
TZfgktH61FPcZJTNPpV3RI+Ap1Ux9yQ3G/e5/d/q9Ak2bS4UqpgipD5/u6fF
iIAzwQvztBTiaNR28QszApuNQwOPTlfiTIV3B51JcODlcuR+vIMmt8yENhsC
k0oDiZraPQw1C+4U2BHclro3tax8iGGWZp+7E8HDuIIZmxUNSG1aOLxwOcHI
HNepZbufImqLSaeOGwH7c6n+DJtGtK7vbB/2JFgyEXk78EYTNNRlMU3rCZqS
nV8+sW3Bs5NfN30NIZiZKf9cPNQKtkAnef82AvlYj+T1gld40qxSk8cRFJHa
Rr0MEaJLboUN7ifQs7hGZbJ2xPuL56fxCM78WrXzkvUbGAuCFY7pBKNupbLY
JDFYh+Ny2/IIEp0aKo0fdaD2++KWrOsEPTcaTrdZvYXLgoiQ2mqCr3HtgvmH
u7B2T3aheiOB3c+a4ztru6HIHzXP6CLwvGwVU24iwafgyAv+qsm/LLbO6g3r
gdM1VgVvihz2imCO2O89fsnY3eVsLofhVJVWw5f3EMv/5LgulUPjnkA4O78X
X6xFveMBcvzmXNup7SOF6I0jcUiUo9Q76tLdUSk4ujU/eOTKMSI30+/P6YNt
QvyyvfVyVAV6qmevkSGwPCiUTeRI8kq5WNkvw5y71f1qpgpYvVvXcSXlA1yS
ECHwVsBlaXI216kfSWmew33JCoRZtnxWE/UjdNrKNuEDBUYa06XxvH/hHnGi
fVBbiVyNiMQA6wGsVvSqUgOVMJRUXWY3DCBi6VtJfqESU47ygpYnDMJ3+i6T
sW9KsIojhNJpBH+39D+N3jSEvXnC9GkPCabobAkffzCEers0LYM9cpR9KKkZ
daQwWLfX/rieAk45Z1vbBRTdDq2iQ3WTO+rvHjbgqHDzAqxlEUoYieZZHPBQ
IVy4xMBiXAn31Bh+8XEVjqUU8rpLhuDBz9sw9liFsgELgZ4vhba4dmDfDwzS
ClIiJf4U48d0vc5pMogOUNrc2EiR2hPcUKPFwLyu7qZfCIXHySxDNofBKX7o
kzNRFBNxizhZUxnELjnP/HiIgu8qC/jHlMGs5Olemlcpyg1L+oztGIwvO6Ir
vk5hFMt+6mrPoFPZ9+pqKUVbbN7jaAcGmSEV4R7lFKbsoOkVjgwmbAP2pdRR
uLQeHN3gzKC7jX9BXUSRZzLy4Kwrg+rUse2i1xQxn/QDa1YxyF6xdf6VDors
zefHpWDg89dPlaslFGY5tUXOqxnUHGx+zhukuKPWZdfpwSDHYTF/o4KC9Yxm
sL0YJEjzg6woRU2Wto69N4N5vrt67n+kmC01DUryYaCh1l6UOUax6MVHy2Jf
Bu+rVsRFfqGI511WF/kxqIu74rjgO4XhWiP2d38G52ZyRiYmKBShbmZzNzD4
DxvTcjw=
             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$4395#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwVzn881HcAx3G/NsZG56SdH+maphxRodT0VhqF0/w6tbgkqqmksimPys4D
/VRmZpVIiGG5WscqStOl3EP5HS0dXeZHPt/7nm9kZG7XH+/H6/H8782N2hcU
o6OlpcXX7EN9Y4Za7w+Hrlaza6TzrhPoeVnE93JckNp+bMpO42WXz1+6yVkH
5YvSJU4a+z3p+iOPE4K4KF6xh8Zh0RN3szjRMDuje/FbjV86HffK4CSgUju4
MVvjgtkb009xUnHYwt/d8AaByOCm3UlONjwyOT9Marxp8xWxarQYNY//nD1b
QmCkFoX7zBXDcFmJaGE1wYJA5dCD0xJ4ZS0+yL9FkPjUHefHbmO960h7/R2C
ORKWXFu7Dmbh/lLnuwTVCq+m5q/qYeWWp3hfR1Afm2e5mUjRtFw3YbCeYPxL
D5Nrex9B7+XKjU8eEuhMVsyyXCCDd9FRG7tGAjd1ZHVwZRNUMk9WchNBU6rL
0wb7ZoyFmdipmwlsMkcmy5QtyLqyc4rVQTAy0SvvdG5D+Q7fIwu7CYrf1MiM
z7bjkSvFV/UQGFuX0v39HUg8aM3TVxCc+a5qR4HtM+QJ/zJxGCR451nRvyu5
CyEpCc0eFEHCUqnE/EE3UML32fuWoLdSerqV+zdYJkmPG6YI3sd25C5KeoFi
Wcm6ezoUeGv0Z3bU9EBiLLzNGFLwKeTuvDFHjkxDveFWMwqJ1lvnvwrvhVuo
/jTHhoIDCTXq4vdBh/113iZ7CmwTlYF0qg8fb5Hns1dQ0KvLFX9x6RVWj8ZF
5HhT2O1S8/wTPwVaPi03T99EoWJDVMG9dwrEa4Vate6hMD5iMWsg5zVKf3/u
V5hCoSrYRzd7XT+WPA0QWOZTSF6fdlky0I8SqW4ou5YC96Vvd1HaP/BaVRYo
kFNYuTw1m7N0AAb7ZhxMDZUIn9s8qd0+gLLYZw28lUqMyzIU8aJBFLzV8SxI
VOK8njAhyHYIFo2MYOyOEmx5VaGOdAhtBe9iXPRpfHRUFOK+fxhGuu8tZmJo
aJUJxQrTNwDV+UtfI40DF8UZpvVvYLvEKcKAq8Jd3gkDVtwIXCKzRn7epgLL
94BDijHB9DPvaftCFXocW9oP1xLw4l/JAogK1/Nh2y+kYNSWOuexyygixG4s
6xkKLRsEftuOjeLHtCuinnIlYte+Hb7QMoprQ9a5xv40hO6lG3k2DE7kpUXK
A2gMqhTijHkMooOoBZWBmp852x1VXAZWtbXX+WE0bpt3JlfZMjh1bkvDmSga
7JODyWvsGexyuzBqeJjGfnVKt9CVwfxUs/X6JTRsU47zK/0YzKw48lnXbzTO
8s3tzfgMnlOv20oqaFz1t+ImBTDIDLsZ4X2DRqnAXegdyEBtH3QwrZZGeMdu
0z4Bg57Wc/m67TSmH/30zedRDG6lT2xv76RBkVZZ8nYG2au2LirqphGXAuFg
NAO/q4sla+U0olnBLdU7Gdw59KRRNEwj39G5V7CXQY6j67lAQsOzQTyvLo7B
fsWlEC5NY/XDe0l28QwW+u/pvT9Gw2Otx6F/DzDQ0+4ozpyg0cNKt9yWwKCv
alVs5BQNzsisrsbvGdTGFjk5/0cjqFBWvjSRwa82RuNqNY351gU5uYcY/A94
0nKu
             "]]},
           Annotation[#, "Charting`Private`Tag$4462#1"]& ]}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0.6},
       DisplayFunction->Identity,
       Epilog->{
         Directive[{
           GrayLevel[0], 
           Dashing[{Small, Small}], 
           Thickness[0.0015]}], 
         LineBox[{{0, 1}, {1, 1}}]},
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Largest Eigenvalue\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox["\"M\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->{FontFamily -> "Times New Roman"},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0, 1}, {0.6, 1.3}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {576., -118.66252583997979}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJwV0XtUzHkYBvBui91sRLt2IqnUUrlsJbn1EEfpgm4buk0Xl4aohGwWQxO6
TpdDqaGUxNBEhdWE1aw928klM5mR6TZGTWr6fee3kora2T/e857PH88573le
i8gDfjv1dHR0fLTz//bcqWp53BfoyjSxuTlnB4HBetO4ToYT9HPtz1hp7Xi5
oLiGsQGW+1yibLX2eia9w2MEIMw0Yq6L1kHRww25jGhoSr+U+GvdvuTM+kxG
IipvZknTtC75YUtqGiMFQem1hqNas6fU/HyOkQ/vrerit8EE27aXCoimHK9n
8W+IQwkMJ9gh7nMFSPzc1dAQTmDtO6hqTK8FOZh++nYEwZHnK1Dw8Q9IZbkX
eqIIZtUad+jqPsJkxyuyqbsI7irWN79Y/QS23Kg/k/cQPGHxZm8fEKGifabu
FxbBkM2aabdi/0bOxNGCfbEEeiP86bOtm/DMJqn5lzgC5wnmXf+qZlR6L1f3
JhA0pzg9f2r7AqMPn2dUHyIw5/aPXB98CSrGPlCeRNA/3NnRuvQVZm/hXv2c
TFD+ob7JKEuMdp51HOcEgZHZNUqplCCAMxLheJogI6ZuV8n815jUfFLckkrw
aS1fueeEFFzJHQynESQ6iGp/bJTBKN6BNS2boLNKlN5i0QZZiXpRYx7BGEtS
tPC3t8hKdWjjFxDYrZs8vqtejiy5j845HoH7FYvdt2d1YKX9pIvWZdq+zMIt
u0M60WNXVVJfSWA/EGgo9emCJW/nfm4VwcxpZIpotAvHCu47+9dp//+oSGBV
3I1YN7t2EyHBXqf6N996KXAjx7STNBLwN0WWPPykwMdTvdHrmrV99ptO7zn/
DjXtiQ8LJQR1/u76+RuU2PJuiBvSQXDCg3O5tkcJjjKeWqYisGj3lJVx3sMg
95ZpKU2wcnlKPsOhB+Yp0127xwlC5r4Y0RX34KQ8i+lpqMFQU6Yijt2LO3sH
5g0yNCgwCEv0m6+CSG/5Z8kCDWZ21F3RE6nwcltg6D0XDb75nR2wIr4P0mvF
eSleGuhcDxMoZnzAgzFhjiBMg4SLgswZTz7gOM9VFX1Igwa7s1OM9/fjmsQn
QJypgbFngv0powHUlB5vrKrQQL7opfiocADhO1ZHGYk0qL6E+cowNQQxp8zf
d2sQKnA2NhtXI7bQw+uMLo2TnFK2/MYgWOu4XZdsaNxSmRUZeVP4OvVfq14v
Gmd5HGbHZgpOxWvO5XnTiPZTW1f5UuhnVluu9aExRyis9gmioHYwoQs300jL
Dn6aEUmBWT6it9WXxh7nQs13RykU/7Rs8K9faVimmHhMrqBQ8/gIJYugMe5y
7HtpJQVl39m36ZE03qjfvargU4ihWsdco2hwg2pCN96mEHzc8s3VaBoTtn4H
OUIK8W7Jkw7vpiFvyb6kL6aQ08+3mxdL437qcJS4lULCmGvwa63zV4UvLJNR
CEjTf5Sxn4bX1cW1bh0U3O7NsRo9QONB0rN/2H0URsJiQ6UJNM4vWpbtO0Dh
bitrcfZBGvGK4gALikJWXrajeyKNBd77Oh9/1N7T5NF27xANA11JOXeYgsyk
LTnuMI2uulUs5iiF2E0ZvguP0BCyypYs/arNC0KDFVpfMDccmpigsJHtXViU
ROM/+QKHmg==
             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$6300#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJwVy2s0lAkAxvFxKaWTjEo7ilZLN2VsIynlqUgkrNvBJgmVJrmlbetQdIwu
plJsq1BIbSWEYS3DFE5bVo1rsssY06TR+8688xbZqWOs/fCc//l9eCwj4vwO
6DIYDK/p/d9dBxSdT0YDnVFyITPmPQF9F7P4IZY9RiZzCpKnzbmdm1/NcsWU
6EgVf9qeL/uqClgB+CbwtPzRtIOiJhqvsaKgEHhyldMeZJ9zucRKAqtoxWSs
gkDhQp+Mi6x0DO/55Jo0SiBtVvWKC6wcRD5dmnGOIBAcUlShpkvQpafXa6cm
MGcqLXSnRQWu52fi6RgBa1+VoiVTgFpJ4ooEDYETrzYid+wPCDVeps+1BBYJ
mBIdHREq5b/cm6FPolbm0i7e3IxbmjoFw5BEM7dgcQjZikfHvm22NyYxvnzL
vLKjf8KCczXZx5SErqbUeLF1G9o8DkV7m5NwmAqv9S9vR6tusJ+jFYn2dPtX
z1aL4djENoi0IbE0i9A8UHXAZHGatJhDgpgYkvTadeGmtsSm04lEyYeGNqPL
3Xi0oFG8fQcJI/PfKLm8B9oYsyobHxL8wzUHC61eY2BTW/XsEBKft5bKo8/0
4etVTkRKFImkda0C05Y3yI7gSz7FkRgqb83stPwbouxytncKia/cnrxVp/5B
yXhu6vFMEjbbDLQHGwaQ3Dl1oOoGiZ3FlocqF0lgoQmWRjwkccJ837Lh0CFE
9z8PdWsgsYYMnNPnJcVBvy7e9y9JzJ+nntX6RQq3y7bcABkJfVFexXf5wxA4
s3f0TJA4Yt/QP9tTBg63rcyTqUSpR0Rh02cZ7A2beKI1SowTZsYj199iWDSp
aHdXosZ/p16Oqxz3y0KyOFwlzrjzbgtG5Lgp/7Euha+E5eCuN3d47xD+V9GL
wEolNm1Iz2GtG0F5rlmv16ASoRZijU73CFKktR2xhiqMt12Sxae9hyRs+fEt
W1XI1Q9L8rNSYKYDvz/uhArzJTXFuq0KiJMZv5+tUmFGSlrAxoRROKd6MhP+
VYHxIKxCZvIBpzZ0DcaAQuLNiksmzR8Q2MwWCq9RaLQ5P4sZS4B52tBhLkGB
uStxzVkjEl7lPQ55lmoMrO3oPikkoVM4I/5UgBqPb8FKHqaE22HuR1GGGnsr
HJjmWiVmejv2p9arkcorSht4qMJHYlzmPK5GmcI8z2g3BRP/dFNfWxrnC3jh
Em8Kr1O9bwSwaUT5Ka3LfSnkGI+5BNvRWCIUPvYKouCSkm0cvo7GxSt7nvEj
KGTXJ/ISHGhEO9ygDU9SMPWw7chzprEsfYG7wT0Km2cWp8z1oaF1TJ7bd5+C
z156cOEPNPqVb7vulVKoe2cbZeFLIyuoeq9bJQW+/QYZ25/G1Gq/YzwhBY8X
4uKAIBoDnVdu6XVTaPdrWnl3H426jInI7l4KWvNWaUU4jRynfavuvKFw+3xL
Y/1+Gp53bQXbJRTWhySOdETSqP/55Yu00em/9Yhae4jG9bXrr/iSFCaXzBMb
HqaRIMsPsKQoLLSq6zTl0li5O2boyRiFn1q8XNkxNPR1ekqyJihwTJYInI7S
kNY4ccO/UHg1uNbdPZaGkHuHbTdJYZtBEiMwjsavS+eMT01R+JwwNLA/nsZ/
ZnB9pQ==
             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$6344#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV03tUzGkYB/BJLZPWJJcYbdkyWBE2iUJfNkQJpSQqTnLZ2nWNFrnMqkGX
dSkMlVC0NpposrWNpEapo+kyMaEaxjSmmnp/v7ZU0sz+9o/3vOdzznOe877P
eb62oXt9dwxjsVjezPn/9tyhrStp83eLdpANWmYQmLhP2qfkOmH6dUOXHeN5
6cLUPO5ysNebqmcz9qpWPErj+uHF8iz5SsYBYX1PLnHDcN+SW3mYcfOcM+6J
3EiItY6jFIxvjl8niOPGYKG365Awk4DPzpt+jpuMsi1NyXZ3CTYF3hJRdCbG
ecy3SrpHYGbgB3nYiPApzSVed59gqk+XtixeDM2JgLWbcgmiZC4Q9hRCX7nL
fqGYYILYosXI6CnqI56LDX8TPFa5v6xZXIpXXYPs1RKC0vA0q0CdFLyMTbPy
Sgh6py0xf/BrBWoSlrYaPycYNpA92mpqFa76ddC6SgJnw7bHG3JeIrxn48hi
GcHLGCdZuX0NbES73z6SE0y+0DFwr6sWgnd9ZVveEHT0KVteza1H/zP9M10L
QWZ7URXnDzna38057dVKwLHOImp1Az7HcRvaOwgSfs7feZP3Gk1BSd4Huwk+
L81W7z6pgFYUmdk7QBDpKBVbljWCV33ULY9FQZkjja+zfQuhzWvzIRMKg+EN
KTOOvsMZzoGCY6YUZi4bod9Z1ISL4/sP94yi4HHbdtfDCS1IeCrrtxtLIcp6
q92HICWeufqf85lIYZbO30zh/Z6Zb1hziTWFseYUW/rlPS7JDwVY8iiYPE0R
TUn9AMv44XkH7SlEOBW9MfVSoaRi7zLNjxSyV4feLP6sgtShbFWDC4Xejkmj
NVc+Ytf8iXMVyyjkb/AwTl6uRlKiWfdKLwonV8WmizVqsDcgv8WPgm2zZ2NG
bCuiL73+duJWCq4LYpK5jhoM99pR5RxBIcimZsBIrkFIZ8aka1FM/6pE1T7+
JxwtCI7bKKAgNAmJ9OVp0fyiOuLYZeb9Lfm3h0m1CPk+vfD5HQrfHOf7uexv
Q+J6c7MlhRRY90JEqjHtGKu0VK6opnDguihxTGk7jDmmPa6tFJ7MPMu22NOB
nIHHH5YYKFh4Hpj1O0cHodQhvYNLo8mhVn5EogM8726/70Ij9wZ46pBOrKgt
+Tp5M41gkbOFtb4Texa79edE0zgVe4vf9FcXalWsIv87NB5orVM4awi2R1Uc
d5fROJsWu61lLZObRscaVg2NMN/OqTk+BOv3jNhczPg7iSTXO4AgRd1s5VpH
I+78lvKEUIJumWKdUwON3c7X6JFHCIoyYw7Ne0vDLmbcqhFMjvo2BwqDNDT0
C6NHKf5k6oNzObafaLzp/Fh/N5uguKLpSSvjCwF5wSsfEpxuulG+t42Gwd73
YCyTkxOSKXyBjvlv3fkbxsye+4crkou7aRQI+rbLXxGc7Hx4WfAvjeRFW2dk
NBIUnNHL1vbQ8LozW/wTs/fmVH27spfGP79VV/LbGF/MKjcZoHHFYf55Hx1B
v5tvnIzxflWqny0hSMMCgfALjR/W/KIs6SFInZ40zeErDROjhswLfQSFIYNV
fYzf5y8K3/aFwO7sqazSIRqS8Iw5c4cIQnlWkkQ9jauTzXoNBmaemWXsQAON
/wDTVJW/
             "]]},
           Annotation[#, "Charting`Private`Tag$6388#1"]& ]}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0.6},
       DisplayFunction->Identity,
       Epilog->{
         Directive[{
           GrayLevel[0], 
           Dashing[{Small, Small}], 
           Thickness[0.0015]}], 
         LineBox[{{0, 1}, {1, 1}}]},
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Largest Eigenvalue\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox[
           "\"\\!\\(\\*SuperscriptBox[\\(M\\), \\(f\\)]\\)\"", FontSize -> 24,
             StripOnInput -> False], TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->{FontFamily -> "Times New Roman"},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0, 1}, {0.6, 1.3}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {192., -355.98757751993935}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[{{{{}, {}, 
          TagBox[
           {GrayLevel[0], AbsoluteThickness[1.6], Opacity[1.], 
            LineBox[CompressedData["
1:eJwV0Hk4lQkbBnC0kEodmkTJkkyRJUWpqTufvpQsg6NGdCqi+BBlCCF9jkkR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             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$6432#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[1, 0, 0], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{0, Small}], LineBox[CompressedData["
1:eJwV0Gk8lAkABnBHYdWO0LGTNEuN1bGqcWSn46mVEh2L2Wi1GkeRolSrkDT9
jIhyTXKFhA4hoYt0rM2yYkOrQ8Yyaab3He9cb7bdbezsh+f3/P5fng+PTfB+
n10Genp6wbr83567pM8eyr5f3Rj0na+jI4FJbrMPiJlOsK7kMmO4BBxL8orq
mevg4V5JJK8l4PW0/+YFJg+9r0qn2G4l4Bc6fj+bGYo4i/YPWeEE3iw55XaG
eRiPsnzmzcklICr54iE74Ce8EpaUhhcS8DS7trKlKAYXZziwykoJ3BrrdKZY
sWjSanjiawTOVlvYe9sdR0HkyaW5LQRKZ2xNPs1Mgv/d8pDoEQLxT8+3bruX
BA+ZxdX+dwS2CYcM5gUI8ZFo5zmSBKbS0YlNRcmQuTKtOjUEjvaJjpKsVJzQ
T12VNpmEd86riC12Z/Hvtmy9n9gkBCb1X6UyRUjQa97L4ZNYuCEr5eYBEXJk
TMlfISR6hPtlr9tE6FK/i7kbRmK+4eIqh5hzEGQvCFqwn8STT+UOfT25uDyW
69mWQGKqOteZlZ6PkURL2bQCEnlv4twatcVgr2mI291Nwn/7xVqFshznbhJm
Xy6Vg3rNMy2bXQEG8YDfzpEjOdBkl69bBVwtj1UecJajPmT/7FuiCpCOiey7
XDkYUauE8csrMf1o83GOuxy/nHz5g1HCZaS6J7V2bJeDc93caI7JNZiy+p1r
BXJMmRDs2DC3FinW1QHGT+Vge49Jf05rAGtFMzfTdwxHur5BnuYu/LuXLeP2
j2FWg/mgvv4DfHJK6g7zoHBr2K2ze+VjGLmnSg2bKDyOuGC1nWyFfthJvVQL
BWi7VWbVkW0IHg/rKFurgMHHqmlW7A5c7e+KTz+ogMsE/5ZvTSfK6k87xRYr
0Jnk1PVkYTcq8luD5/6qACuT+Hh17HeIjfUlUrUCxLh48PnSHqDa72yhlRLl
75s6GGd70fXvp0qBuxIM68uURNKH2NSC9MJIJdL3NO4unf8HrrDrqEXZSnxY
UyUJT+yH5sONKxN3lDjMaW2Y+fML3D9m/lY4oIS4pjXtmc0rsPML920yUOGf
iL7CBXGvEZ/ZMfO2nQqL1hprdzcNoGgRJDYeKmwoswmrmzUIySpZWudeFY5Y
77T9c4cYt2PLzhekq7CY/H5K/+YhaLkZ9rzrKliaKUxa/x7CklN02MYuFSY9
KKydV/QnZr1eps2Sq7DXqenlZ17DMO2p0zLM1KjaGFza8mEYv9mZ+KcuUYMm
Zk8bzR3B5HiOMmGzGo2+GwxF6yQwJVe2lUaqkeghLGkYlSCjUJH5XZoaNm88
X1wSvsX07X1B866owV2eJGJyRrGem0JZt6mxY273R/3eUZhabSIejuj2O84M
HxC8w+roElmSgQZ5kwIP+8yXIvlz3rqJuRpYDjaWGbRK4ck1sq/jajA5QcD7
JloGl6GXtxP8NdC7Glg7bPEefO/0phmHNThYUHvG4vF72L47H/A4S4P7i1JM
zKMIvLVlNFTVaGDueXDxSQYJeajc8lC7BgNf/94b20wikL/HeOOoBjeKMV8S
KIcUY+uM9Gn8WOtibq2Vw7NY1WthReOE8KJg4NoYHu2752G/nEa11LqQsYnC
sGvQOUdvGikXhPzBLRTEd+JPXdY51EfOrvGmwNfmxFj50JjT3Hxjsx+FF2ce
eBn60jidEfAkPZhCZTmjp4dHI9wlX2kaS2F9FrEl2p+GbdJ0D+NKCtLQ7KnX
d9LQuh77vP8KhTlylxIWn8ZL+UhPZRWFhqpRhxydM/3qf1xfR0F2aI97XBCN
iYU+h4TNFOSPjLd6hNAYeJZRbNhLYVuO4fOR3TTuJI+H9D6nkPVPuqtfGA3R
ip0LLr2g0OFgn9+hs1eFQ8O3gxTs8s5514XTuHf0abtARsFU7FdyPIJG7tfO
Gd4khR0m8YRS5+jhIp4NRYGzut5p114a9pv2iR9qKCREhbZ47aMxSb+vPHOc
whrXQW2LzkONKyL4f1OwqY5ayYmk0RxxacnSTxQynWYeqdD5PGsKPTGh+9f5
ec0XUTT+A1PcHJs=
             "]]},
           
           Annotation[#, 
            "Charting`Private`Tag$6476#1"]& ]}, {}, {}}, {{{}, {}, 
          TagBox[
           {RGBColor[0, 0, 1], AbsoluteThickness[1.6], Opacity[1.], 
            Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV1Hk41AkYB3BXms2GkWIszcqRI7JSrvTNsrGIVY5taxFR1Arr3iNkpHWE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             "]]},
           Annotation[#, "Charting`Private`Tag$6520#1"]& ]}, {}, {}}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->{True, True},
       AxesLabel->{None, None},
       AxesOrigin->{0, 0.6},
       DisplayFunction->Identity,
       Epilog->{
         Directive[{
           GrayLevel[0], 
           Dashing[{Small, Small}], 
           Thickness[0.0015]}], 
         LineBox[{{0, 1}, {1, 1}}]},
       Frame->{{True, True}, {True, True}},
       FrameLabel->{{
          FormBox[
           StyleBox[
           "\"Largest Eigenvalue\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}, {
          FormBox[
           StyleBox["\"\[Kappa]\"", FontSize -> 24, StripOnInput -> False], 
           TraditionalForm], None}},
       FrameTicks->FrontEndValueCache[{{Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
           Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
          Automatic, {{0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {2., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {1.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.2, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.4, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.6, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.8, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {1., 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
              AbsoluteThickness[0.1]}}, {0.05, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.1, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.15, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.25, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.3, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.35, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.45, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.5, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.55, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.65, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.7, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.75, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.85, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.9, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}, {0.95, 
             FormBox[
              TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 
             0.}, {
              AbsoluteThickness[0.1]}}}}}],
       GridLines->{None, None},
       GridLinesStyle->Directive[
         GrayLevel[0.5, 0.4]],
       ImagePadding->All,
       LabelStyle->{FontFamily -> "Times New Roman"},
       Method->{
        "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
         AbsolutePointSize[6], "ScalingFunctions" -> None, 
         "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& ), "CopiedValueFunction" -> ({
             (Identity[#]& )[
              Part[#, 1]], 
             (Identity[#]& )[
              Part[#, 2]]}& )}},
       PlotRange->{{0, 1}, {0.6, 2}},
       PlotRangeClipping->True,
       PlotRangePadding->{{0, 0}, {0, 0}},
       Ticks->{Automatic, Automatic}], {576., -355.98757751993935}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->900,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{
  3.845059832868832*^9, {3.8450598677050033`*^9, 3.845059903297719*^9}, {
   3.845059947038973*^9, 3.845060027237296*^9}, 3.845060131111989*^9, 
   3.8450602126649885`*^9, 3.8450602782995396`*^9, {3.845060341149753*^9, 
   3.8450603579214325`*^9}, 3.845060488087657*^9, {3.845060554295874*^9, 
   3.8450605650092072`*^9}, 3.845060628664947*^9, 3.845060696115427*^9, 
   3.8450782818197117`*^9, {3.847500182905197*^9, 3.8475001984215283`*^9}, {
   3.8477470099795103`*^9, 3.8477470548206964`*^9}, {3.847747119558817*^9, 
   3.8477471688989897`*^9}, 3.84774720974938*^9, {3.8477472514317007`*^9, 
   3.847747281106658*^9}, 3.8477473865931597`*^9, 3.8477474555050917`*^9, 
   3.8477475736151247`*^9, {3.847747649240165*^9, 3.847747667976133*^9}, 
   3.847747709428343*^9, 3.8477477587671432`*^9, 3.847748444405678*^9, 
   3.8477488982461233`*^9, 3.847749021748189*^9, 3.847749239320578*^9, 
   3.8477492910259123`*^9, 3.847749725130234*^9, 3.8477499582353888`*^9, 
   3.8477499929405527`*^9, 3.8477500418108196`*^9, 3.847750104513503*^9, 
   3.8490421106339006`*^9, 3.8852542803049583`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"a96be428-c1c6-4986-ba9e-2cf6553d1238"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.847750504200794*^9, 3.847750504342948*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"b645c103-e07b-444b-9743-0e27110ea522"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"WorkDrive", " ", "=", "\"\<YOUR MACHINE\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"figname3", " ", "=", " ", "\"\<Figure_1.eps\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Export", "[", 
  RowBox[{
   RowBox[{"WorkDrive", "<>", "figname3"}], ",", "Figure1"}], "]"}]}], "Input",
 CellChangeTimes->{{3.8450781672893353`*^9, 3.845078206629794*^9}, {
  3.845078239027119*^9, 3.8450782411016927`*^9}, {3.8475001728766212`*^9, 
  3.8475001780035253`*^9}, {3.847748018202686*^9, 3.8477480253097043`*^9}, {
  3.8852542283585587`*^9, 3.8852542303111987`*^9}, {3.885254273711753*^9, 
  3.8852543159537916`*^9}, {3.885254384072235*^9, 
  3.8852543875343337`*^9}},ExpressionUUID->"71ec1240-e11f-42e6-a7d2-\
ef8caef4b74d"],

Cell[BoxData["\<\"C:\\\\Users\\\\cgib4223\\\\Dropbox\\\\Anticipation and \
Estability\\\\Drafts\\\\Figures\\\\Figure_1.eps\"\>"], "Output",
 CellChangeTimes->{{3.885254280960387*^9, 3.88525431935349*^9}},
 CellLabel->"Out[30]=",ExpressionUUID->"5c302e41-02be-4366-a3aa-2fc2828fcfa2"]
}, Open  ]],

Cell[BoxData[""], "Input",
 CellChangeTimes->{{3.845078226102976*^9, 3.84507824478234*^9}},
 CellLabel->"In[24]:=",ExpressionUUID->"1c8103a9-d446-47db-86b1-230851c4c543"]
},
WindowSize->{1484, 941},
WindowMargins->{{-8, Automatic}, {Automatic, 0}},
Magnification:>2. Inherited,
FrontEndVersion->"11.3 for Microsoft Windows (64-bit) (March 6, 2018)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 2001, 56, 292, "Input",ExpressionUUID->"91f35138-8d69-4d58-b225-39ad68149a62"],
Cell[2584, 80, 671, 17, 65, "Output",ExpressionUUID->"68f9af6a-fac1-4bed-9b8f-38b699d42eee"],
Cell[3258, 99, 372, 8, 65, "Output",ExpressionUUID->"022247b5-654f-48c5-b8c4-ed9d0a42d29b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3667, 112, 4192, 111, 666, "Input",ExpressionUUID->"65099b3b-d3ca-469e-b624-ab2104b13853"],
Cell[7862, 225, 946, 27, 150, "Output",ExpressionUUID->"2cbdc684-9ec1-4d4d-ab1f-73ca6f4c16d0"],
Cell[8811, 254, 574, 16, 65, "Output",ExpressionUUID->"ff8d8d3e-7300-42f6-8796-67f83e082e36"],
Cell[9388, 272, 242, 5, 65, "Output",ExpressionUUID->"4d53ed8c-2a68-40f4-a8f2-49d5589a8a3b"],
Cell[9633, 279, 242, 5, 65, "Output",ExpressionUUID->"c1263589-744c-44f4-b3ac-ee756e56565a"],
Cell[9878, 286, 1294, 36, 198, "Output",ExpressionUUID->"1ea8241f-ee53-45e8-8a12-3a2e2a30330e"],
Cell[11175, 324, 1294, 36, 198, "Output",ExpressionUUID->"e3b4e413-94f5-40b6-b3c3-e1444ec7aa5a"],
Cell[12472, 362, 1742, 49, 272, "Output",ExpressionUUID->"f0db2aed-e089-4c2a-a64b-dfe4d3ec094f"]
}, Open  ]],
Cell[14229, 414, 1941, 54, 136, "Input",ExpressionUUID->"29d8c1d7-d48d-4ade-80fe-ed20a4c2f1f3"],
Cell[CellGroupData[{
Cell[16195, 472, 24420, 589, 2720, "Input",ExpressionUUID->"b55b0b1f-5c59-4c11-ae68-af744d117ace"],
Cell[40618, 1063, 62934, 1334, 1172, "Output",ExpressionUUID->"a96be428-c1c6-4986-ba9e-2cf6553d1238"]
}, Open  ]],
Cell[103567, 2400, 225, 3, 136, "Input",ExpressionUUID->"b645c103-e07b-444b-9743-0e27110ea522"],
Cell[CellGroupData[{
Cell[103817, 2407, 772, 16, 136, "Input",ExpressionUUID->"71ec1240-e11f-42e6-a7d2-ef8caef4b74d"],
Cell[104592, 2425, 283, 3, 90, "Output",ExpressionUUID->"5c302e41-02be-4366-a3aa-2fc2828fcfa2"]
}, Open  ]],
Cell[104890, 2431, 170, 2, 57, "Input",ExpressionUUID->"1c8103a9-d446-47db-86b1-230851c4c543"]
}
]
*)

